# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from chat_server_connector.models.chat_member_get import ChatMemberGet
from chat_server_connector.models.chat_message import ChatMessage
from chat_server_connector.models.chat_type import ChatType

class ChatGetWithMembersAndMessages(BaseModel):
    """
    ChatGetWithMembersAndMessages
    """
    id: StrictInt = Field(...)
    uuid: StrictStr = Field(...)
    chat_type: ChatType = Field(...)
    avatar_id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    messaging_enabled: StrictBool = Field(...)
    permalink_enabled: StrictBool = Field(...)
    is_visible: StrictBool = Field(...)
    topic_slug: Optional[StrictStr] = None
    is_muted: Optional[StrictBool] = False
    created_at: StrictInt = Field(...)
    last_updated_at: StrictInt = Field(...)
    members: Optional[conlist(ChatMemberGet)] = None
    messages: Optional[conlist(ChatMessage)] = None
    __properties = ["id", "uuid", "chat_type", "avatar_id", "name", "description", "messaging_enabled", "permalink_enabled", "is_visible", "topic_slug", "is_muted", "created_at", "last_updated_at", "members", "messages"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChatGetWithMembersAndMessages:
        """Create an instance of ChatGetWithMembersAndMessages from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in members (list)
        _items = []
        if self.members:
            for _item in self.members:
                if _item:
                    _items.append(_item.to_dict())
            _dict['members'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in messages (list)
        _items = []
        if self.messages:
            for _item in self.messages:
                if _item:
                    _items.append(_item.to_dict())
            _dict['messages'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChatGetWithMembersAndMessages:
        """Create an instance of ChatGetWithMembersAndMessages from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ChatGetWithMembersAndMessages.parse_obj(obj)

        _obj = ChatGetWithMembersAndMessages.parse_obj({
            "id": obj.get("id"),
            "uuid": obj.get("uuid"),
            "chat_type": obj.get("chat_type"),
            "avatar_id": obj.get("avatar_id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "messaging_enabled": obj.get("messaging_enabled"),
            "permalink_enabled": obj.get("permalink_enabled"),
            "is_visible": obj.get("is_visible"),
            "topic_slug": obj.get("topic_slug"),
            "is_muted": obj.get("is_muted") if obj.get("is_muted") is not None else False,
            "created_at": obj.get("created_at"),
            "last_updated_at": obj.get("last_updated_at"),
            "members": [ChatMemberGet.from_dict(_item) for _item in obj.get("members")] if obj.get("members") is not None else None,
            "messages": [ChatMessage.from_dict(_item) for _item in obj.get("messages")] if obj.get("messages") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector.api.chats_api import ChatsApi  # noqa: E501


class TestChatsApi(unittest.IsolatedAsyncioTestCase):
    """ChatsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ChatsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_chat_api_chat_ai_usage_insert(self) -> None:
        """Test case for chat_api_chat_ai_usage_insert

        Chat Ai Usage Insert  # noqa: E501
        """
        pass

    async def test_chat_api_chat_delete(self) -> None:
        """Test case for chat_api_chat_delete

        Chat Delete  # noqa: E501
        """
        pass

    async def test_chat_api_chat_get(self) -> None:
        """Test case for chat_api_chat_get

        Chat Get  # noqa: E501
        """
        pass

    async def test_chat_api_chat_join(self) -> None:
        """Test case for chat_api_chat_join

        Chat Join  # noqa: E501
        """
        pass

    async def test_chat_api_chat_leave(self) -> None:
        """Test case for chat_api_chat_leave

        Chat Leave  # noqa: E501
        """
        pass

    async def test_chat_api_chat_mark_as_read(self) -> None:
        """Test case for chat_api_chat_mark_as_read

        Chat Mark As Read  # noqa: E501
        """
        pass

    async def test_chat_api_chat_member_ban(self) -> None:
        """Test case for chat_api_chat_member_ban

        Chat Member Ban  # noqa: E501
        """
        pass

    async def test_chat_api_chat_members_list(self) -> None:
        """Test case for chat_api_chat_members_list

        Chat Members List  # noqa: E501
        """
        pass

    async def test_chat_api_chat_members_update(self) -> None:
        """Test case for chat_api_chat_members_update

        Chat Members Update  # noqa: E501
        """
        pass

    async def test_chat_api_chat_message_delete(self) -> None:
        """Test case for chat_api_chat_message_delete

        Chat Message Delete  # noqa: E501
        """
        pass

    async def test_chat_api_chat_message_get(self) -> None:
        """Test case for chat_api_chat_message_get

        Chat Message Get  # noqa: E501
        """
        pass

    async def test_chat_api_chat_messages_add(self) -> None:
        """Test case for chat_api_chat_messages_add

        Chat Messages Add  # noqa: E501
        """
        pass

    async def test_chat_api_chat_messages_insert(self) -> None:
        """Test case for chat_api_chat_messages_insert

        Chat Messages Insert  # noqa: E501
        """
        pass

    async def test_chat_api_chat_messages_list(self) -> None:
        """Test case for chat_api_chat_messages_list

        Chat Messages List  # noqa: E501
        """
        pass

    async def test_chat_api_chat_mute(self) -> None:
        """Test case for chat_api_chat_mute

        Chat Mute  # noqa: E501
        """
        pass

    async def test_chat_api_chat_patch(self) -> None:
        """Test case for chat_api_chat_patch

        Chat Patch  # noqa: E501
        """
        pass

    async def test_chat_api_chat_private_join(self) -> None:
        """Test case for chat_api_chat_private_join

        Chat Private Join  # noqa: E501
        """
        pass

    async def test_chat_api_chat_session_start(self) -> None:
        """Test case for chat_api_chat_session_start

        Chat Session Start  # noqa: E501
        """
        pass

    async def test_chat_api_chat_session_stop(self) -> None:
        """Test case for chat_api_chat_session_stop

        Chat Session Stop  # noqa: E501
        """
        pass

    async def test_chat_api_chat_unmute(self) -> None:
        """Test case for chat_api_chat_unmute

        Chat Unmute  # noqa: E501
        """
        pass

    async def test_chat_api_chat_update(self) -> None:
        """Test case for chat_api_chat_update

        Chat Update  # noqa: E501
        """
        pass

    async def test_chat_api_chats_add(self) -> None:
        """Test case for chat_api_chats_add

        Chats Add  # noqa: E501
        """
        pass

    async def test_chat_api_chats_list(self) -> None:
        """Test case for chat_api_chats_list

        Chats List  # noqa: E501
        """
        pass

    async def test_chat_api_chats_list_available(self) -> None:
        """Test case for chat_api_chats_list_available

        Chats List Available  # noqa: E501
        """
        pass

    async def test_chat_api_get_total_unread_messages(self) -> None:
        """Test case for chat_api_get_total_unread_messages

        Get Total Unread Messages  # noqa: E501
        """
        pass

    async def test_chat_api_stop_agent_run(self) -> None:
        """Test case for chat_api_stop_agent_run

        Stop Agent Run  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.response_wrapper_chat_session_get_with_chat_data import ResponseWrapperChatSessionGetWithChatData  # noqa: E501

class TestResponseWrapperChatSessionGetWithChatData(unittest.TestCase):
    """ResponseWrapperChatSessionGetWithChatData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperChatSessionGetWithChatData:
        """Test ResponseWrapperChatSessionGetWithChatData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperChatSessionGetWithChatData`
        """
        model = ResponseWrapperChatSessionGetWithChatData()  # noqa: E501
        if include_optional:
            return ResponseWrapperChatSessionGetWithChatData(
                done = True,
                result = chat_server_connector.models.chat_session_get_with_chat_data.ChatSessionGetWithChatData(
                    id = 56, 
                    chat_id = 56, 
                    creator_id = 56, 
                    credentials = chat_server_connector.models.credentials.Credentials(), 
                    chat_session_type = 'TEXT', 
                    created_at = 56, 
                    ended_at = 56, 
                    last_activity_at = 56, 
                    messages = [
                        chat_server_connector.models.chat_message_read.ChatMessageRead(
                            text = '', 
                            file_id = '', 
                            id = 56, 
                            chat_message_type = 'TEXT', 
                            run_id = '', 
                            chat_id = 56, 
                            chat_member_id = 56, 
                            added_at = 56, 
                            attachments = [
                                chat_server_connector.models.chat_message_attachment_read.ChatMessageAttachmentRead(
                                    file_id = '', 
                                    attachment_type = 'IMAGE', 
                                    id = 56, )
                                ], 
                            chat_session = chat_server_connector.models.chat_session_get.ChatSessionGet(
                                id = 56, 
                                chat_id = 56, 
                                creator_id = 56, 
                                credentials = chat_server_connector.models.credentials.Credentials(), 
                                chat_session_type = 'TEXT', 
                                created_at = 56, 
                                ended_at = 56, 
                                last_activity_at = 56, ), )
                        ], 
                    chat = chat_server_connector.models.chat_get_with_members.ChatGetWithMembers(
                        id = 56, 
                        uuid = '', 
                        chat_type = 'SOLO', 
                        avatar_id = '', 
                        name = '', 
                        description = '', 
                        messaging_enabled = True, 
                        permalink_enabled = True, 
                        is_visible = True, 
                        topic_slug = '', 
                        is_muted = True, 
                        created_at = 56, 
                        last_updated_at = 56, 
                        members = [
                            chat_server_connector.models.chat_member_get.ChatMemberGet(
                                role = null, 
                                user_id = 56, 
                                bot_id = 56, 
                                id = 56, 
                                chat_id = 56, 
                                added_at = 56, 
                                last_seen_at = 56, 
                                is_removed = True, 
                                is_banned = True, 
                                is_muted = True, 
                                user = chat_server_connector.models.contact.Contact(
                                    id = 56, 
                                    role = 1, 
                                    nickname = '', 
                                    personal_description = '', 
                                    first_name = '', 
                                    last_name = '', 
                                    avatar_id = '', 
                                    is_online = True, 
                                    address = null, 
                                    phone_number = '', 
                                    is_public_email = True, 
                                    is_public_phone_number = True, 
                                    is_public_city = True, 
                                    is_public_country = True, 
                                    email = '', ), 
                                bot = chat_server_connector.models.ai_assistant_get.AiAssistantGet(
                                    allow_text = True, 
                                    allow_voice = True, 
                                    approved_urls = [
                                        ''
                                        ], 
                                    avatar_id = '', 
                                    banned_keywords = [
                                        ''
                                        ], 
                                    conversation_starter = '', 
                                    conversation_style = 'formal', 
                                    created_at = 56, 
                                    deleted_at = 56, 
                                    function = 'support', 
                                    goals = [
                                        chat_server_connector.models.ai_assistant_goal_get.AiAssistantGoalGet(
                                            additional_prompt = '', 
                                            ai_assistant_id = 56, 
                                            course_ids = [
                                                56
                                                ], 
                                            created_at = 56, 
                                            engagement = 56, 
                                            engagement_opt_out_duration = 56, 
                                            engagement_preset = chat_server_connector.models.goal_engagement_preset_get.GoalEngagementPresetGet(
                                                created_at = 56, 
                                                engagement = 56, 
                                                engagement_opt_out_duration = 56, 
                                                id = 56, 
                                                max_engagement_count = 56, 
                                                max_engagement_period = 56, 
                                                max_total_engagement_count = 56, 
                                                name = '', 
                                                order = 56, ), 
                                            engagement_preset_id = 56, 
                                            id = 56, 
                                            interactions_summary = chat_server_connector.models.goal_interactions_summary.GoalInteractionsSummary(
                                                is_available = True, 
                                                last_engagement_at = 56, 
                                                last_opt_out_at = 56, 
                                                recent_interaction_count = 56, 
                                                total_interaction_count = 56, ), 
                                            is_active = True, 
                                            is_fullfilled = True, 
                                            last_updated_at = 56, 
                                            max_engagement_count = 56, 
                                            max_engagement_period = 56, 
                                            max_total_engagement_count = 56, 
                                            name = '', 
                                            page_url = '', 
                                            primary_course = chat_server_connector.models.course_public.CoursePublic(
                                                description = '', 
                                                id = 56, 
                                                modules = [
                                                    chat_server_connector.models.course_module_public.CourseModulePublic(
                                                        id = 56, 
                                                        lessons = [
                                                            chat_server_connector.models.module_lesson_public.ModuleLessonPublic(
                                                                id = 56, 
                                                                title = '', )
                                                            ], 
                                                        public_description = '', 
                                                        short_description = '', 
                                                        title = '', )
                                                    ], 
                                                payment_type = 'paid', 
                                                title = '', 
                                                url = '', ), 
                                            primary_course_id = 56, )
                                        ], 
                                    id = 56, 
                                    is_active = True, 
                                    is_available = True, 
                                    is_live = True, 
                                    knowledgebase_state = chat_server_connector.models.knowledgebase_state.KnowledgebaseState(
                                        course_data = chat_server_connector.models.collection_state.CollectionState(
                                            error_message = '', 
                                            status = 'unavailable', ), ), 
                                    last_updated_at = 56, 
                                    lexicon_items = [
                                        chat_server_connector.models.ai_assistant_lexicon_item.AiAssistantLexiconItem(
                                            ai_assistant_id = 56, 
                                            deleted_at = 56, 
                                            id = 56, 
                                            order = 56, 
                                            pronounciation = '', 
                                            term = '', )
                                        ], 
                                    name = '', 
                                    prefer_voice = True, 
                                    system_prompt = '', 
                                    system_prompt_support = '', 
                                    system_prompt_tutor = '', 
                                    voice_id = 56, ), )
                            ], ), 
                    tokens_used = 1.337, ),
                error = ''
            )
        else:
            return ResponseWrapperChatSessionGetWithChatData(
                done = True,
        )
        """

    def testResponseWrapperChatSessionGetWithChatData(self):
        """Test ResponseWrapperChatSessionGetWithChatData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
